@@ -299,7 +299,7 @@ void CustomProjectPart::openProject(const QString &dirName, const QString &proje
         int r = KMessageBox::questionYesNo(mainWindow()->main(),
                                            i18n("This project does not contain any files yet.\n"
                                                 "Populate it with all C/C++/Java files below "
-                                                "the project directory?"));
+                                                "the project directory?"), QString::null, i18n("Populate"), i18n("Do Not Populate"));
         if (r == KMessageBox::Yes)
             populateProject();
     }
@@ -422,23 +422,7 @@ DomUtil::PairList CustomProjectPart::runEnvironmentVars() const
   */
 QString CustomProjectPart::runDirectory() const
 {
-    QDomDocument &dom = *projectDom();
-
-    QString directoryRadioString = DomUtil::readEntry(dom, "/kdevcustomproject/run/directoryradio");
-    QString DomMainProgram = DomUtil::readEntry(dom, "/kdevcustomproject/run/mainprogram");
-
-    if ( directoryRadioString == "build" )
-        return buildDirectory();
-
-    if ( directoryRadioString == "custom" )
-        return DomUtil::readEntry(dom, "/kdevcustomproject/run/customdirectory");
-
-    int pos = DomMainProgram.findRev('/');
-    if (pos != -1)
-        return buildDirectory() + "/" + DomMainProgram.left(pos);
-
-    return buildDirectory() + "/" + DomMainProgram;
-
+    return defaultRunDirectory("kdevcustomproject");
 }
 
 
@@ -812,7 +796,12 @@ void CustomProjectPart::parseMakefile(const QString& filename)
 
       if (includedMakefilesRe.search(str) != -1)
       {
-         m_makefilesToParse.push(includedMakefilesRe.cap(1).simplifyWhiteSpace());
+         QString includedMakefile=includedMakefilesRe.cap(1).simplifyWhiteSpace();
+         /*special optimization for makefiles generated with the new cmake makefile generator:
+          it creates a tiny makefile for each object and a tiny dependency file for each object,
+          these dependency files can be skipped here, Alex */
+         if (!includedMakefile.endsWith(".depends.make"))
+            m_makefilesToParse.push(includedMakefile);
       }
       else if (re.search(str) != -1)
       {
