@@ -1,6 +1,7 @@
+%{H_TEMPLATE}
 
-#ifndef __KFILE_$APPNAMEUC$_H__
-#define __KFILE_$APPNAMEUC$_H__
+#ifndef __KFILE_%{APPNAMEUC}_H__
+#define __KFILE_%{APPNAMEUC}_H__
 
 /**
  * Note: For further information look into <$KDEDIR/include/kfilemetainfo.h>
@@ -9,15 +10,15 @@
 
 class QStringList;
 
-class $APPNAME$Plugin: public KFilePlugin
+class %{APPNAME}Plugin: public KFilePlugin
 {
     Q_OBJECT
     
 public:
-    $APPNAME$Plugin( QObject *parent, const char *name, const QStringList& args );
+    %{APPNAME}Plugin( QObject *parent, const char *name, const QStringList& args );
     
     virtual bool readInfo( KFileMetaInfo& info, uint what);
 };
 
-#endif // __KFILE_$APPNAMEUC$_H__
+#endif // __KFILE_%{APPNAMEUC}_H__
 
