@@ -103,6 +103,7 @@ void GDBOutputWidget::slotReceivedStdout(const char* line)
         m_gdbView->append(QString("<font color=\"blue\">").append( line ).append("</font>") );
     else
         m_gdbView->append(line);
+    m_gdbView->scrollToBottom();
 }
 
 /***************************************************************************/
@@ -110,6 +111,7 @@ void GDBOutputWidget::slotReceivedStdout(const char* line)
 void GDBOutputWidget::slotReceivedStderr(const char* line)
 {
     m_gdbView->append(QString("<font color=\"red\">").append( line ).append("</font>") );
+    m_gdbView->scrollToBottom();
 }
 
 /***************************************************************************/
@@ -148,10 +150,19 @@ void GDBOutputWidget::slotDbgStatus(const QString &, int statusFlag)
     }
 }
 
+/***************************************************************************/
+
+void GDBOutputWidget::focusInEvent(QFocusEvent */*e*/)
+{
+    m_gdbView->scrollToBottom();
+    m_userGDBCmdEditor->setFocus();
+}
+
 /***************************************************************************/
 /***************************************************************************/
 /***************************************************************************/
 }
 
+
 #include "gdboutputwidget.moc"
 
