@@ -132,7 +132,8 @@ void VariableTree::slotContextMenu(KListView *, QListViewItem *item)
     setSelected(item, true);    // Need to select this item.
 
     if (item->parent()) {
-        KPopupMenu popup(item->text(VarNameCol), this);
+        KPopupMenu popup(this);
+        popup.insertTitle(item->text(VarNameCol));
         int idRemoveWatch = -1;
         if (dynamic_cast<WatchRoot*>(findRoot(item)))
             idRemoveWatch = popup.insertItem( i18n("Remove Watch Variable") );
