@@ -1,3 +1,18 @@
+#include "rubysupport_part.h"
+#include "rubyconfigwidget.h"
+#include "domutil.h"
+
+#include "qtdesignerrubyintegration.h"
+#include "rubyimplementationwidget.h"
+
+#include "kdevcore.h"
+#include "kdevmainwindow.h"
+#include "kdevlanguagesupport.h"
+#include "kdevpartcontroller.h"
+#include "kdevproject.h"
+#include "kdevappfrontend.h"
+#include "kdevplugininfo.h"
+
 #include <qwhatsthis.h>
 #include <qtimer.h>
 #include <qfileinfo.h>
@@ -14,21 +29,6 @@
 #include <kapplication.h>
 #include <qregexp.h>
 
-#include "kdevcore.h"
-#include "kdevmainwindow.h"
-#include "kdevlanguagesupport.h"
-#include "kdevpartcontroller.h"
-#include "kdevproject.h"
-#include "kdevappfrontend.h"
-#include "kdevplugininfo.h"
-
-#include "rubysupport_part.h"
-#include "rubyconfigwidget.h"
-#include "domutil.h"
-
-#include "qtdesignerrubyintegration.h"
-#include "rubyimplementationwidget.h"
-
 typedef KDevGenericFactory<RubySupportPart> RubySupportFactory;
 static const KDevPluginInfo data("kdevrubysupport");
 K_EXPORT_COMPONENT_FACTORY( libkdevrubysupport, RubySupportFactory( data ) )
@@ -40,7 +40,9 @@ RubySupportPart::RubySupportPart(QObject *parent, const char *name, const QStrin
   setXMLFile("kdevrubysupport.rc");
 
   KAction *action;
-  action = new KAction( i18n("&Run"), "exec",Key_F9,this, SLOT(slotRun()),actionCollection(), "build_execute" );
+  action = new KAction( i18n("&Run"), "exec", SHIFT + Key_F9,
+                        this, SLOT(slotRun()),
+                        actionCollection(), "build_execute" );
   action->setToolTip(i18n("Run"));
   action->setWhatsThis(i18n("<b>Run</b><p>Starts an application."));
   action->setIcon("ruby_run.png");
@@ -73,6 +75,12 @@ void RubySupportPart::projectOpened()
 {
   kdDebug() << "projectOpened()" << endl;
 
+  // Save the $SHELL environment variable in order to restore it
+  // on project close, and switch to using irb in the terminal
+  m_savedShell.sprintf("SHELL=%s", getenv("SHELL"));
+  m_shell.sprintf("SHELL=%s", shell().latin1());
+  putenv(qstrdup(m_shell.data()));
+
   connect( project(), SIGNAL(addedFilesToProject(const QStringList &)),
   	this, SLOT(addedFilesToProject(const QStringList &)) );
   connect( project(), SIGNAL(removedFilesFromProject(const QStringList &)),
@@ -444,15 +452,19 @@ void RubySupportPart::parse(const QString &fileName)
 }
 
 
-void RubySupportPart::slotRun () {
-	QFileInfo program(mainProgram());
+void RubySupportPart::slotRun ()
+{
+    // if we can't save all parts, then the user canceled
+    if ( partController()->saveAllFiles() == false )
+        return;
+    QFileInfo program(mainProgram());
     QString cmd = QString("%1 -K%2 -C%3 -I%4 %5 %6")
-	                      .arg(interpreter())
-						  .arg(characterCoding())
-						  .arg(program.dirPath())
-						  .arg(program.dirPath())
-						  .arg(program.fileName())
-						  .arg(programArgs());
+                      .arg(interpreter())
+                      .arg(characterCoding())
+                      .arg(program.dirPath())
+                      .arg(program.dirPath())
+                      .arg(program.fileName())
+                      .arg(programArgs());
     startApplication(cmd);
 }
 
@@ -462,6 +474,12 @@ QString RubySupportPart::interpreter() {
     return prog;
 }
 
+QString RubySupportPart::shell() {
+    QString shell = DomUtil::readEntry(*projectDom(), "/kdevrubysupport/run/shell");
+    if (shell.isEmpty()) shell = "irb";
+    return shell;
+}
+
 QString RubySupportPart::mainProgram() {
 	QString prog;
 	int runMainProgram = DomUtil::readIntEntry(*projectDom(), "/kdevrubysupport/run/runmainprogram");
@@ -545,6 +563,10 @@ KDevDesignerIntegration *RubySupportPart::designer(KInterfaceDesigner::DesignerT
 
 void RubySupportPart::projectClosed( )
 {
+	if (!m_savedShell.isNull()) {
+        putenv(qstrdup(m_savedShell.data()));
+    }
+
     for (QMap<KInterfaceDesigner::DesignerType, KDevDesignerIntegration*>::const_iterator it =  m_designers.begin();
         it != m_designers.end(); ++it)
     {
