@@ -21,6 +21,7 @@
 #include "kdevpartcontroller.h"
 #include "kdevproject.h"
 #include "codemodel.h"
+#include "kdevplugininfo.h"
 
 #include "sqlsupport_part.h"
 #include "sqlconfigwidget.h"
@@ -29,11 +30,11 @@
 #include "domutil.h"
 
 typedef KDevGenericFactory<SQLSupportPart> SQLSupportFactory;
-static const KAboutData data("kdevsqlsupport", I18N_NOOP("Language"), "1.0");
-K_EXPORT_COMPONENT_FACTORY( libkdevsqlsupport, SQLSupportFactory( &data ) )
+static const KDevPluginInfo data("kdevsqlsupport");
+K_EXPORT_COMPONENT_FACTORY( libkdevsqlsupport, SQLSupportFactory( data ) )
 
 SQLSupportPart::SQLSupportPart( QObject *parent, const char *name, const QStringList& )
-        : KDevLanguageSupport ( "KDevPart", "kdevpart", parent, name ? name : "SQLSupportPart" )
+        : KDevLanguageSupport ( &data, parent, name ? name : "SQLSupportPart" )
 {
     setInstance( SQLSupportFactory::instance() );
     setXMLFile( "kdevsqlsupport.rc" );
@@ -55,7 +56,7 @@ SQLSupportPart::SQLSupportPart( QObject *parent, const char *name, const QString
     connect( partController(), SIGNAL( savedFile( const KURL& ) ), this, SLOT( savedFile( const KURL& ) ) );
 
     m_widget = new SqlOutputWidget();
-    mainWindow()->embedOutputView( m_widget, "SQL", "Output of SQL commands" );
+    mainWindow()->embedOutputView( m_widget, i18n( "SQL" ), i18n( "Output of SQL commands" ) );
     QWhatsThis::add(m_widget, i18n("<b>Output of SQL commands</b><p>This window shows the output of SQL commands being executed. It can display results of SQL \"select\" commands in a table."));
 }
 
@@ -131,7 +132,7 @@ void SQLSupportPart::loadConfig()
 
 void SQLSupportPart::projectConfigWidget( KDialogBase *dlg )
 {
-    QVBox *vbox = dlg->addVBoxPage( QString( "SQL" ), i18n( "Specify Your Database Connections" ) );
+    QVBox *vbox = dlg->addVBoxPage( QString( "SQL" ), i18n( "Specify Your Database Connections" ), BarIcon("source", KIcon::SizeMedium) );
     SqlConfigWidget *w = new SqlConfigWidget( (QWidget*)vbox, "SQL config widget" );
     w->setProjectDom( projectDom() );
     w->loadConfig();
