@@ -53,8 +53,6 @@
 #include <kparts/componentfactory.h>
 #include <kio/netaccess.h>
 #include <qfile.h>
-#include <qdir.h>
-#include <qtextstream.h>
 #include <kmacroexpander.h>
 #include <karchive.h>
 #include <ktar.h>
@@ -68,32 +66,42 @@
 #include "kdevversioncontrol.h"
 #include "kdevmakefrontend.h"
 #include "kdevpartcontroller.h"
+#include "kdevappfrontend.h"
+#include "kdevplugininfo.h"
 #include "kdevlicense.h"
 #include "kdevcore.h"
 #include "appwizardfactory.h"
 #include "appwizardpart.h"
 #include "filepropspage.h"
 #include "misc.h"
-#include "dataform.h"
+#include "profilesupport.h"
+#include "filetemplate.h"
+
+#include "propeditor/property.h"
+#include "propeditor/multiproperty.h"
+#include "propeditor/propertylist.h"
+#include "propeditor/propertyeditor.h"
 
 AppWizardDialog::AppWizardDialog(AppWizardPart *part, QWidget *parent, const char *name)
-    : AppWizardDialogBase(parent, name,true), m_pCurrentAppInfo(0)
+    : AppWizardDialogBase(parent, name,true), m_pCurrentAppInfo(0), 
+	m_profileSupport(new ProfileSupport(part))
 {
 	kdDebug( 9000 ) << "  ** AppWizardDialog::AppWizardDialog()" << endl;
 
 	m_customOptions = 0L;
+	loadLicenses();
     connect( this, SIGNAL( selected( const QString & ) ), this, SLOT( pageChanged() ) );
-    
+
 	helpButton()->hide();
     templates_listview->header()->hide();
 	templates_listview->setColumnWidthMode(0, QListView::Maximum);	//to provide horiz scrollbar.
-	
+
 	m_templatesMenu = new KPopupMenu(templates_listview);
 	m_templatesMenu->insertItem(i18n("&Add to Favorites"), this, SLOT(addTemplateToFavourites()));
-	
+
 	m_favouritesMenu = new KPopupMenu(favourites_iconview);
 	m_favouritesMenu->insertItem(i18n("&Remove Favorite"), this, SLOT(removeFavourite()));
-	
+
     m_pathIsValid=false;
     m_part = part;
     m_projectLocationWasChanged=false;
@@ -101,7 +109,7 @@ AppWizardDialog::AppWizardDialog(AppWizardPart *part, QWidget *parent, const cha
     m_tempFiles.setAutoDelete(true);
 
     KConfig *config = kapp->config();
-	
+
 	//config->setGroup("AppWizard");
 	//templates_tabwidget->setCurrentPage(config->readNumEntry("CurrentTab", 0));
 
@@ -117,15 +125,15 @@ AppWizardDialog::AppWizardDialog(AppWizardPart *part, QWidget *parent, const cha
     QStringList::Iterator it;
     for (it = m_templateNames.begin(); it != m_templateNames.end(); ++it) {
         kdDebug(9010) << (*it) << endl;
-		
 
         ApplicationInfo *info = new ApplicationInfo;
+		info->propValues = new PropertyLib::PropertyList();
 		info->templateFile = KGlobal::dirs()->findResource("apptemplates", *it);
         info->templateName = (*it);
-		
+
 		KConfig templateConfig(info->templateFile);
         templateConfig.setGroup("General");
-		
+
         info->name = templateConfig.readEntry("Name");
         info->icon = templateConfig.readEntry("Icon");
         info->comment = templateConfig.readEntry("Comment");
@@ -143,7 +151,7 @@ AppWizardDialog::AppWizardDialog(AppWizardPart *part, QWidget *parent, const cha
         categories.append(category);
         info->category = category;
 		info->sourceArchive = templateConfig.readEntry("Archive");
-		
+
 		// Grab includes list
 		QStringList groups = templateConfig.groupList();
 		groups.remove("General");
@@ -155,14 +163,14 @@ AppWizardDialog::AppWizardDialog(AppWizardPart *part, QWidget *parent, const cha
 			if( type == "include" )  // Add value
 			{
 				info->includes.append( templateConfig.readEntry( "File" ) );
-				kdDebug() << "Adding: " << templateConfig.readEntry( "File" ) << endl;
+				kdDebug(9010) << "Adding: " << templateConfig.readEntry( "File" ) << endl;
 			}
 		}
-		
+
 		// Build builtins map to bootstrap.
 		QString source = kdevRoot( info->templateName );
 		info->subMap.insert("kdevelop", source );
-		
+
 		// Add includes to the main template...
 		QStringList::Iterator include = info->includes.begin();
 		for( ; include != info->includes.end(); ++include)
@@ -172,10 +180,10 @@ AppWizardDialog::AppWizardDialog(AppWizardPart *part, QWidget *parent, const cha
 				QString file = KMacroExpander::expandMacros( ( *include ), info->subMap);
 				KConfig tmpCfg( file );
 				tmpCfg.copyTo( "", &templateConfig);
-				kdDebug() << "Merging: " << tmpCfg.name() << endl;
+				kdDebug(9010) << "Merging: " << tmpCfg.name() << endl;
 			}
 		}
-		
+
 		groups = templateConfig.groupList();  // Must get this again since its changed!
 		group = groups.begin();
 		for(  ; group != groups.end(); ++group)
@@ -188,11 +196,13 @@ AppWizardDialog::AppWizardDialog(AppWizardPart *part, QWidget *parent, const cha
 				QString name = templateConfig.readEntry( "Value" );
 				QString label = templateConfig.readEntry( "Comment" );
 				QString type = templateConfig.readEntry( "ValueType", "String" );
-				autoKey key( name, label);
-				QVariant value = templateConfig.readPropertyEntry( "Default", QVariant::nameToType( type.latin1() ) );
-				value.cast( QVariant::nameToType( type.latin1() ) );  // fix this in kdelibs...
-				info->subValues.insert( key, value );
-			} 
+				QVariant::Type variantType = QVariant::nameToType( type.latin1());
+				QVariant value = templateConfig.readPropertyEntry( "Default", variantType );
+				value.cast( variantType );  // fix this in kdelibs...
+				if( !name.isEmpty() && !label.isEmpty() )
+					info->propValues->addProperty( new PropertyLib::Property( (int)variantType, name, label, value ) );
+				
+			}
 			else if( type == "install" ) // copy dir
 			{
 				installFile file;
@@ -220,6 +230,11 @@ AppWizardDialog::AppWizardDialog(AppWizardPart *part, QWidget *parent, const cha
 				dir.perms = templateConfig.readNumEntry("Perms", 0777 );
 				info->dirList.append(dir);
 			}
+			else if( type == "finishcmd" )
+			{
+                                info->finishCmd=templateConfig.readPathEntry("Command");
+                                info->finishCmdDir=templateConfig.readPathEntry("Directory");
+			}
 			else if( type == "ui")
 			{
 				QString name = templateConfig.readPathEntry("File");
@@ -230,8 +245,8 @@ AppWizardDialog::AppWizardDialog(AppWizardPart *part, QWidget *parent, const cha
 				info->message = templateConfig.readEntry( "Comment" );
 			}
 		}
-	
-		
+
+
         m_appsInfo.append(info);
     }
 
@@ -254,10 +269,10 @@ AppWizardDialog::AppWizardDialog(AppWizardPart *part, QWidget *parent, const cha
                           << ait.current()->category << endl;
         ait.current()->item = item;
     }
-	
+
 	//Load favourites from config
 	populateFavourites();
-	
+
 	QString author, email;
     AppWizardUtil::guessAuthorAndEmail(&author, &email);
     author_edit->setText(author);
@@ -266,7 +281,7 @@ AppWizardDialog::AppWizardDialog(AppWizardPart *part, QWidget *parent, const cha
     dest_edit->setURL(defaultProjectsDir);
     dest_edit->setMode(KFile::Directory|KFile::ExistingOnly|KFile::LocalOnly);
 
-//    loadVcs();
+    loadVcs();
 
     //    addPage(m_sdi_fileprops_page,"Class/File Properties");
 
@@ -284,9 +299,9 @@ AppWizardDialog::AppWizardDialog(AppWizardPart *part, QWidget *parent, const cha
                                                    appname_edit,
                                                    "AppNameValidator");
     appname_edit->setValidator(appname_edit_validator);
-    
+
     // insert the licenses into the license_combo
-    QDict< KDevLicense > lics( m_part->core()->licenses() );
+    QDict< KDevLicense > lics( licenses() );
     QDictIterator< KDevLicense > dit(lics);
     int idx=1;
     for( ; dit.current(); ++dit )
@@ -295,44 +310,74 @@ AppWizardDialog::AppWizardDialog(AppWizardPart *part, QWidget *parent, const cha
         if( dit.currentKey() == "GPL" )
             license_combo->setCurrentItem( idx - 1 );
     }
+
+	connect( license_combo, SIGNAL(activated(int)), this, SLOT(licenseChanged()) );
 	
 	m_custom_options_layout = new QHBoxLayout( custom_options );
 	m_custom_options_layout->setAutoAdd(true);
+	
+	showTemplates(false);
 }
 
 AppWizardDialog::~AppWizardDialog()
 {}
-/*
+
 void AppWizardDialog::loadVcs()
 {
-    m_vcsForm = new VcsForm();
+	m_vcsForm = new VcsForm();
 
-    int i=0;
-    m_vcsForm->combo->insertItem( i18n("no version control system", "None"), i );
-    m_vcsForm->stack->addWidget( 0, i++ );
+	int i=0;
+	m_vcsForm->combo->insertItem( i18n("no version control system", "None"), i );
+	m_vcsForm->stack->addWidget( 0, i++ );
 
-    // We query for all vcs plugins for KDevelop
-    QStringList availableVcs = m_part->registeredVersionControls();
+	// We query for all vcs integrators for KDevelop
+	KTrader::OfferList offers = KTrader::self()->query("KDevelop/VCSIntegrator", "");
+	KTrader::OfferList::const_iterator serviceIt = offers.begin();
+	for (; serviceIt != offers.end(); ++serviceIt)
+	{
+		KService::Ptr service = *serviceIt;
+		kdDebug(9010) << "AppWizardDialog::loadVcs: creating vcs integrator "
+			<< service->name() << endl;
 
-    for(QStringList::const_iterator it( availableVcs.begin() ); it != availableVcs.end(); ++it)
-    {
-        KDevVersionControl *vcs = m_part->versionControlByName( (*it) );
-        QString vcsName = vcs->uid();
+		KLibFactory *factory = KLibLoader::self()->factory(QFile::encodeName(service->library()));
+		if (!factory) {
+			QString errorMessage = KLibLoader::self()->lastErrorMessage();
+			kdDebug(9010) << "There was an error loading the module " << service->name() << endl <<
+			"The diagnostics is:" << endl << errorMessage << endl;
+			exit(1);
+		}
+		QStringList args;
+		QObject *obj = factory->create(0, service->name().latin1(),
+									"KDevVCSIntegrator", args);
+		KDevVCSIntegrator *integrator = (KDevVCSIntegrator*) obj;
 
-        QWidget *newProjectWidget = vcs->newProjectWidget( m_vcsForm->stack );
-        if (newProjectWidget) {
-            m_vcsForm->combo->insertItem( vcsName, i );
-            m_vcsForm->stack->addWidget( newProjectWidget, i++ );
-        }
-        else
-        {
-            kdDebug( 9000 ) << "  ** Warning: VCS has not widget. Skipping. " << endl;
-        }
-    }
+		if (!integrator)
+			kdDebug(9010) << "    failed to create vcs integrator " << service->name() << endl;
+		else
+		{
+			kdDebug(9010) << "    success" << endl;
 
-    addPage( m_vcsForm, i18n("Version Control System") );
+			QString vcsName = service->property("X-KDevelop-VCS").toString();
+			m_vcsForm->combo->insertItem(vcsName, i);
+			m_integrators.insert(vcsName, integrator);
+
+			VCSDialog *vcs = integrator->integrator(m_vcsForm->stack);
+			if (vcs)
+			{
+				m_integratorDialogs[i] = vcs;
+				QWidget *w = vcs->self();
+				if (w)
+					m_vcsForm->stack->addWidget(w, i++);
+				else
+					kdDebug(9010) << "    integrator widget is 0" << endl;
+			}
+			else
+				kdDebug(9010) << "    integrator is 0" << endl;
+		}
+	}
+
+	addPage(m_vcsForm, i18n("Version Control System"));
 }
-*/
 
 void AppWizardDialog::updateNextButtons()
 {
@@ -349,7 +394,7 @@ void AppWizardDialog::updateNextButtons()
 
 void AppWizardDialog::textChanged()
 {
-    licenseChanged();
+//    licenseChanged();
 
 	updateNextButtons();
 }
@@ -365,11 +410,11 @@ void AppWizardDialog::licenseChanged()
 			edit->setText( QString::null );
 		}
 	} else {
-		KDevLicense* lic = m_part->core()->licenses()[ license_combo->currentText() ];
+		KDevLicense* lic = licenses()[ license_combo->currentText() ];
 		for (it = m_fileTemplates.begin(); it != m_fileTemplates.end(); ++it) {
 			QString style = (*it).style;
 			QMultiLineEdit *edit = (*it).edit;
-			
+
 			KDevFile::CommentingStyle commentStyle = KDevFile::CPPStyle;
 			if (style == "PStyle") {
 				commentStyle = KDevFile::PascalStyle;
@@ -378,7 +423,7 @@ void AppWizardDialog::licenseChanged()
 			} else if (style == "ShellStyle") {
 				commentStyle = KDevFile::BashStyle;
 			}
-			
+
 			QString text;
 			text = lic->assemble( commentStyle, author_edit->text(), email_edit->text() , 0 );
 			edit->setText(text);
@@ -407,11 +452,11 @@ void AppWizardDialog::accept()
         projectLocationChanged();
         return;
     }
-	
+
 	QString source = kdevRoot( m_pCurrentAppInfo->templateName );
 
 	// Unpack template archive to temp dir, and get the name
-	
+
 	KTempDir archDir;
 	archDir.setAutoDelete(true);
 	KTar templateArchive( source + "/" + m_pCurrentAppInfo->sourceArchive, "application/x-gzip" );
@@ -427,39 +472,64 @@ void AppWizardDialog::accept()
 		return;
 	}
 	templateArchive.close();
-			
+
 	// Build KMacroExpander map
-	m_customOptions->dataForm()->fillPropertyMap(&m_pCurrentAppInfo->subMap); 
+	//m_customOptions->dataForm()->fillPropertyMap(&m_pCurrentAppInfo->subMap);
+	PropertyLib::PropertyList::Iterator idx = m_pCurrentAppInfo->propValues->begin();
+	for( ; idx != m_pCurrentAppInfo->propValues->end(); ++idx)
+		m_pCurrentAppInfo->subMap.insert( idx.data()->name(), idx.data()->value().toString() );
 	
 	m_pCurrentAppInfo->subMap.insert("src", archDir.name() );
 	m_pCurrentAppInfo->subMap.insert("dest", finalLoc_label->text() );
 	m_pCurrentAppInfo->subMap.insert("APPNAME", appname_edit->text() );
 	m_pCurrentAppInfo->subMap.insert("APPNAMELC", appname_edit->text().lower() );
+	m_pCurrentAppInfo->subMap.insert("APPNAMESC", QString(appname_edit->text()[0]).upper() + appname_edit->text().mid(1));
 	m_pCurrentAppInfo->subMap.insert("APPNAMEUC", appname_edit->text().upper() );
 	m_pCurrentAppInfo->subMap.insert("AUTHOR", author_edit->text() );
 	m_pCurrentAppInfo->subMap.insert("EMAIL", email_edit->text() );
 	m_pCurrentAppInfo->subMap.insert("VERSION", version_edit->text());
-	m_pCurrentAppInfo->subMap.insert("LICENSE", license_combo->currentText() );
 	m_pCurrentAppInfo->subMap.insert( "I18N", "i18n" );
+	m_pCurrentAppInfo->subMap.insert("YEAR", QString::number( QDate::currentDate().year() ) );
+	
+	// This isn't too pretty, but we have several templates that use KAboutData::License_${LICENSE}
+	// and unsurprisingly, KAboutData doesn't cover every imaginable case.
+	// These are the licenses known to KDE-3.2 KAboutData, KDevelop doesn't have all of these as prepared options today
+	QString license = license_combo->currentText();
+	if ( license == "GPL" || license == "GPL_V2" || license == "LGPL" || license == "LGPL_V2"||
+		license == "BSD" || license == "Artistic" || license == "QPL" || license == "QPL_V1_0" )
+	{
+		m_pCurrentAppInfo->subMap.insert("LICENSE", license );
+	}
+	else
+	{
+		m_pCurrentAppInfo->subMap.insert("LICENSE", "Custom" );
+	}
+
 
 	QStringList cleanUpSubstMap;
 	cleanUpSubstMap << "src" << "I18N" << "kdevelop";
-	
+
 	// Add template files to the fileList
 	installDir templateDir;
 	templateDir.dir = "%{dest}/templates";
 	m_pCurrentAppInfo->dirList.prepend(templateDir);
-	
+
 	installDir baseDir;
 	baseDir.dir = "%{dest}";
 	m_pCurrentAppInfo->dirList.prepend( baseDir );
+
+	// This is too silly for words, but it's either this or reimplementing FileTemplate
+	QString tempProjectDomSource = "<!DOCTYPE kdevelop><kdevelop><general><author>%1</author><email>%2</email><version>%3</version></general></kdevelop>";
+	tempProjectDomSource = tempProjectDomSource.arg( author_edit->text() ).arg( email_edit->text() ).arg( version_edit->text() );
+	QDomDocument tempProjectDom;
+	tempProjectDom.setContent( tempProjectDomSource ); 
 	
     QValueList<AppWizardFileTemplate>::Iterator it;
     for (it = m_fileTemplates.begin(); it != m_fileTemplates.end(); ++it) {
         KTempFile *tempFile = new KTempFile();
         m_tempFiles.append(tempFile);
 
-		QString templateText( (*it).edit->text() );
+		QString templateText( FileTemplate::makeSubstitutions( tempProjectDom, (*it).edit->text() ) );
 		QFile f;
 		f.open(IO_WriteOnly, tempFile->handle());
 		QTextStream temps(&f);
@@ -476,14 +546,14 @@ void AppWizardDialog::accept()
 		file.isXML = false;
 		m_pCurrentAppInfo->fileList.append( file );
     }
-	
+
 	// Add license file to the file list
 	QString licenseFile, licenseName = i18n("Custom");
-    
+
     if( license_combo->currentItem() != 0 )
     {
         licenseName = license_combo->currentText();
-        KDevLicense* lic = m_part->core()->licenses()[ licenseName ];
+        KDevLicense* lic = licenses()[ licenseName ];
         if( lic )
         {
             QStringList files( lic->copyFiles() );
@@ -497,11 +567,11 @@ void AppWizardDialog::accept()
 				file.isXML = false;
 				m_pCurrentAppInfo->fileList.append( file );
 			}
-			
-			m_pCurrentAppInfo->subMap.insert("LICENSEFILE", files.first()  ); 
+
+			m_pCurrentAppInfo->subMap.insert("LICENSEFILE", files.first()  );
         }
     }
-	
+
 	// Run macro expander on both the dir map and file maps
 	QValueList<installFile>::Iterator fileIt = m_pCurrentAppInfo->fileList.begin();
 	for( ; fileIt != m_pCurrentAppInfo->fileList.end(); ++fileIt)
@@ -509,20 +579,20 @@ void AppWizardDialog::accept()
 		(*fileIt).source = KMacroExpander::expandMacros((*fileIt).source , m_pCurrentAppInfo->subMap);
 		(*fileIt).dest = KMacroExpander::expandMacros((*fileIt).dest , m_pCurrentAppInfo->subMap);
 	}
-	
+
 	QValueList<installArchive>::Iterator archIt = m_pCurrentAppInfo->archList.begin();
 	for( ; archIt != m_pCurrentAppInfo->archList.end(); ++archIt)
 	{
 		(*archIt).source = KMacroExpander::expandMacros((*archIt).source , m_pCurrentAppInfo->subMap);
 		(*archIt).dest = KMacroExpander::expandMacros((*archIt).dest , m_pCurrentAppInfo->subMap);
 	}
-	
+
 	QValueList<installDir>::Iterator dirIt = m_pCurrentAppInfo->dirList.begin();
 	for( ; dirIt != m_pCurrentAppInfo->dirList.end(); ++dirIt)
 	{
 		(*dirIt).dir = KMacroExpander::expandMacros((*dirIt).dir , m_pCurrentAppInfo->subMap);
 	}
-	
+
 	QMap<QString,QString>::Iterator mapIt( m_pCurrentAppInfo->subMap.begin() );
 	for( ; mapIt != m_pCurrentAppInfo->subMap.end(); ++mapIt )
 	{
@@ -532,7 +602,7 @@ void AppWizardDialog::accept()
 		escaped.replace( ">", "&gt;" );
 		m_pCurrentAppInfo->subMapXML.insert( mapIt.key(), escaped );
 	}
-	
+
 	// Create dirs
 	dirIt = m_pCurrentAppInfo->dirList.begin();
 	for( ; dirIt != m_pCurrentAppInfo->dirList.end(); ++dirIt)
@@ -542,7 +612,7 @@ void AppWizardDialog::accept()
 		{
 			if( ! KIO::NetAccess::mkdir( (*dirIt).dir, this ) )
 			{
-				KMessageBox::sorry(this, QString( i18n("The directory %1 cannot be created.")).arg( (*dirIt).dir ) );
+				KMessageBox::sorry(this, i18n("The directory %1 cannot be created.").arg( (*dirIt).dir ) );
 				return;
 			}
 		}
@@ -561,25 +631,25 @@ void AppWizardDialog::accept()
 			}
 			else
 			{
-				KMessageBox::sorry(this, QString( i18n("The archive %1 cannot be opened.")).arg( (*archIt).source ) );
+				KMessageBox::sorry(this, i18n("The archive %1 cannot be opened.").arg( (*archIt).source ) );
 				archive.close();
 				return;
 			}
 			archive.close();
 		}
-	
+
 	}
-	
+
 	// Copy files & Process
 	fileIt = m_pCurrentAppInfo->fileList.begin();
 	for( ; fileIt != m_pCurrentAppInfo->fileList.end(); ++fileIt)
 	{
-		kdDebug( 9000 ) << "Process file " << (*fileIt).source << endl;
+		kdDebug( 9010 ) << "Process file " << (*fileIt).source << endl;
 		if( m_pCurrentAppInfo->subMap[(*fileIt).option] != "false" )
 		{
 			if( !copyFile( *fileIt ) )
 			{
-				KMessageBox::sorry(this, QString( i18n("The file %1 cannot be created.")).arg( (*fileIt).dest) );
+				KMessageBox::sorry(this, i18n("The file %1 cannot be created.").arg( (*fileIt).dest) );
 				return;
 			}
 			setPermissions(*fileIt);
@@ -592,29 +662,36 @@ void AppWizardDialog::accept()
       dest_edit->setFocus();
       return;
     }
-/* 
-    if (m_vcsForm->stack->id(m_vcsForm->stack->visibleWidget())) {
-        KDevVersionControl* pVC = m_part->versionControlByName( m_vcsForm->combo->currentText() );
-        if (pVC) {
-			kdDebug( 9000 ) << "Creating new project with selected VCS ..." << endl;
-            pVC->createNewProject(finalLoc_label->text());
-        }
-		else
-		{
-			kdDebug( 9000 ) << "Could not grab the selected VCS: " << m_vcsForm->combo->currentText() << endl;
-		}
-    }
-*/    
-	KMessageBox::information(this, KMacroExpander::expandMacros(m_pCurrentAppInfo->message, m_pCurrentAppInfo->subMap));
-	
+
+//	KMessageBox::information(this, KMacroExpander::expandMacros(m_pCurrentAppInfo->message, m_pCurrentAppInfo->subMap));
+
 	QStringList::Iterator cleanIt = cleanUpSubstMap.begin();
 	for(;cleanIt != cleanUpSubstMap.end(); ++cleanIt )
 	{
 		m_pCurrentAppInfo->subMap.remove( *cleanIt );
 	}
 
+        if  (!m_pCurrentAppInfo->finishCmd.isEmpty())
+           if (KDevAppFrontend *appFrontend = m_part->extension<KDevAppFrontend>("KDevelop/AppFrontend"))
+              appFrontend->startAppCommand(KMacroExpander::expandMacros(m_pCurrentAppInfo->finishCmdDir, m_pCurrentAppInfo->subMap), KMacroExpander::expandMacros(m_pCurrentAppInfo->finishCmd, m_pCurrentAppInfo->subMap), false);
+
 	openAfterGeneration();
-	
+
+	int id = m_vcsForm->stack->id(m_vcsForm->stack->visibleWidget());
+	if (id)
+	{
+		VCSDialog *vcs = m_integratorDialogs[id];
+		if (vcs)
+		{
+			kdDebug(9010) << "vcs integrator dialog is ready" << endl;
+			vcs->accept();
+		}
+		else
+			kdDebug(9010) << "no vcs integrator dialog" << endl;
+	}
+	else
+		kdDebug(9010) << "vcs integrator wasn't selected" << endl;
+
 	QWizard::accept();
 }
 
@@ -624,6 +701,10 @@ bool AppWizardDialog::copyFile( const installFile& file )
 		copyFile( file.source, file.dest, file.isXML, file.process );
 }
 
+#include <sys/types.h> 
+#include <sys/stat.h> 
+#include <unistd.h> 
+
 bool AppWizardDialog::copyFile( const QString &source, const QString &dest, bool isXML, bool process )
 {
 	kdDebug( 9010 ) << "Copy: " << source << " to " << dest << endl;
@@ -632,6 +713,7 @@ bool AppWizardDialog::copyFile( const QString &source, const QString &dest, bool
 		// Process the file and save it at the destFile location
 		QFile inputFile( source);
 		QFile outputFile( dest );
+
 		const QMap<QString,QString> &subMap = isXML ?
 			m_pCurrentAppInfo->subMapXML : m_pCurrentAppInfo->subMap;
 		if( inputFile.open( IO_ReadOnly ) && outputFile.open(IO_WriteOnly) )
@@ -640,6 +722,11 @@ bool AppWizardDialog::copyFile( const QString &source, const QString &dest, bool
 			QTextStream output( &outputFile );
 			while( !input.atEnd() )
 				output << KMacroExpander::expandMacros(input.readLine(), subMap) << "\n";
+			// Preserve file mode...
+			struct stat fmode;
+			::fstat( inputFile.handle(), &fmode);
+			::fchmod( outputFile.handle(), fmode.st_mode );
+
 		}
 		else
 		{
@@ -659,16 +746,16 @@ bool AppWizardDialog::copyFile( const QString &source, const QString &dest, bool
 void AppWizardDialog::unpackArchive( const KArchiveDirectory *dir, const QString &dest, bool process )
 {
 	KIO::NetAccess::mkdir( dest , this );
-	kdDebug() << "Dir : " << dir->name() << " at " << dest << endl;
+	kdDebug(9010) << "Dir : " << dir->name() << " at " << dest << endl;
 	QStringList entries = dir->entries();
-	kdDebug() << "Entries : " << entries.join(",") << endl;
-	
+	kdDebug(9010) << "Entries : " << entries.join(",") << endl;
+
 	KTempDir tdir;
-	
+
 	QStringList::Iterator entry = entries.begin();
 	for( ; entry != entries.end(); ++entry )
 	{
-		
+
 		if( dir->entry( (*entry) )->isDirectory()  )
 		{
 			const KArchiveDirectory *file = (KArchiveDirectory *)dir->entry( (*entry) );
@@ -689,7 +776,7 @@ void AppWizardDialog::unpackArchive( const KArchiveDirectory *dir, const QString
 				// ( where should we currently get that info from? )
 				if ( !copyFile( QDir::cleanDirPath(tdir.name()+"/"+file->name()), dest + "/" + file->name(), false, process ) )
 				{
-					KMessageBox::sorry(this, QString( i18n("The file %1 cannot be created.")).arg( dest) );
+					KMessageBox::sorry(this, i18n("The file %1 cannot be created.").arg( dest) );
 					return;
 				}
 				setPermissions(file, dest + "/" + file->name());
@@ -703,7 +790,7 @@ void AppWizardDialog::templatesTreeViewClicked(QListViewItem *item)
 {
 	if( m_customOptions )
 		delete m_customOptions;
-		
+
     // Delete old file template pages
     while (!m_fileTemplates.isEmpty()) {
         QMultiLineEdit *edit = m_fileTemplates.first().edit;
@@ -732,12 +819,15 @@ void AppWizardDialog::templatesTreeViewClicked(QListViewItem *item)
         //projectNameChanged(); // set the dest new
 
 		// Populate new custom options form
-		m_customOptions = new AutoForm( &m_pCurrentAppInfo->subValues, custom_options );
-		
-		custom_options->adjustSize();
+		m_customOptions = new PropertyLib::PropertyEditor( custom_options );
+		m_customOptions->populateProperties(info->propValues);
 		
+
         // Create new file template pages
         QStringList l = QStringList::split(",", info->fileTemplates);
+        if (l.empty()) //if the app template doesn't show file templates, we need to set another m_lastPage, aleXXX
+           m_lastPage=m_vcsForm;
+
         QStringList::ConstIterator it = l.begin();
         while (it != l.end()) {
             AppWizardFileTemplate fileTemplate;
@@ -758,7 +848,8 @@ void AppWizardDialog::templatesTreeViewClicked(QListViewItem *item)
             addPage(edit, i18n("Template for .%1 Files").arg(fileTemplate.suffix));
             m_fileTemplates.append(fileTemplate);
         }
-        textChanged(); // calls licenseChanged() && update Next button state
+        licenseChanged();	// to populate the template views
+        textChanged(); // update Next button state
     } else {
 	m_customOptions=0;
         m_pCurrentAppInfo=0;
@@ -780,8 +871,8 @@ void AppWizardDialog::destButtonClicked(const QString& dir)
         QDir newDir (dir);
         kdDebug(9010) << "DevPrjDir == newdir?: " << defPrjDir.absPath() << " == " << newDir.absPath() << endl;
         if (defPrjDir != newDir) {
-            if (KMessageBox::questionYesNo(this, i18n("Set default project location to: ") + newDir.absPath() + "?",
-                                           i18n("New Project")) == KMessageBox::Yes)
+            if (KMessageBox::questionYesNo(this, i18n("Set default project location to: %1?").arg( newDir.absPath() ),
+                                           i18n("New Project"), i18n("Set"), i18n("Do Not Set")) == KMessageBox::Yes)
             {
                 config->writePathEntry("DefaultProjectsDir", newDir.absPath() + "/");
                 config->sync();
@@ -840,6 +931,7 @@ void AppWizardDialog::insertCategoryIntoTreeView(const QString &completeCategory
             //pParentItem->setOpen(true);
             kdDebug(9010) << "Category: " << category << endl;
             m_categoryMap.insert(category,pParentItem);
+            m_categoryItems.append(pParentItem);
         } else {
             pParentItem = item;
         }
@@ -860,27 +952,55 @@ ApplicationInfo *AppWizardDialog::templateForItem(QListViewItem *item)
 void AppWizardDialog::openAfterGeneration()
 {
 	QString projectFile( finalLoc_label->text() + "/" + appname_edit->text().lower() + ".kdevelop" );
-	
+
 	// Read the DOM of the newly created project
 	QFile file( projectFile );
 	if( !file.open( IO_ReadOnly ) )
 		return;
 	QDomDocument projectDOM;
-	projectDOM.setContent( &file );
+	
+	int errorLine, errorCol;
+	QString errorMsg;
+	bool success = projectDOM.setContent( &file, &errorMsg, &errorLine, &errorCol);
 	file.close();
+	if ( !success )
+	{
+		KMessageBox::sorry( 0, i18n("This is not a valid project file.\n"
+				"XML error in line %1, column %2:\n%3")
+				.arg(errorLine).arg(errorCol).arg(errorMsg));
+		return;
+	}
 
 	// DOM Modifications go here
 	DomUtil::writeMapEntry( projectDOM, "substmap", m_pCurrentAppInfo->subMap );
 
-////////////////////////	
+	//save the selected vcs
+	KTrader::OfferList offers = KTrader::self()->query("KDevelop/VCSIntegrator", QString("[X-KDevelop-VCS]=='%1'").arg(m_vcsForm->combo->currentText()));
+	if (offers.count() == 1)
+	{
+		KService::Ptr service = offers.first();
+		DomUtil::writeEntry(projectDOM, "/general/versioncontrol", service->property("X-KDevelop-VCSPlugin").toString());
+	}
+
+	
+	KConfig * config = kapp->config();
+	config->setGroup("IgnorePerDefault");
+	QStringList ignoreparts = config->readListEntry( "KDevelop" );
+	DomUtil::writeListEntry( projectDOM, "/general/ignoreparts", "part", ignoreparts );
+	
+	
+//FIXME PROFILES!!!!!!!!
+//BEGIN Plugin Profile
+
+/*	QString category = m_pCurrentAppInfo->category;
+	if ( category.left( 1 ) == "/" )
+	{
+		category = category.right( category.length() -1 );
+	}
+
+	QString profile = Profiles::getProfileForCategory( category );
+	QStringList loadList = Profiles::getPluginsForProfile( profile );
 
-	QStringList loadList = QStringList::split( ',', "KDevBookmarks,KDevCTags2,KDevClassView,KDevFileView,KDevQuickOpen" );
-	QString lang = DomUtil::readEntry(projectDOM, "/general/primarylanguage");
-	if ((lang == "C") || (lang == "C++"))
-		loadList << "KDevDebugger" << "KDevDoxygen";
-	QString bs = DomUtil::readEntry(projectDOM, "/general/projectmanagement");
-	if ((bs == "KDevAutoProject") || (bs == "KDevKDEAutoProject"))
-		loadList << "KDevdistpart";
 	QStringList ignoreList;
 
 	KTrader::OfferList offers = KTrader::self()->query("KDevelop/Plugin", "[X-KDevelop-Scope] == 'Project'");
@@ -894,9 +1014,9 @@ void AppWizardDialog::openAfterGeneration()
 		++itt;
 	}
 
-	DomUtil::writeListEntry( projectDOM, "/general/ignoreparts", "part", ignoreList );
+	DomUtil::writeListEntry( projectDOM, "/general/ignoreparts", "part", ignoreList );*/
 
-////////////////////////
+//END Plugin Profile
 
 	// write the dom back
 	if( !file.open( IO_WriteOnly ) )
@@ -904,10 +1024,10 @@ void AppWizardDialog::openAfterGeneration()
 	QTextStream ts( &file );
 	ts << projectDOM.toString(2);
 	file.close();
-	
+
 	// open the new project
 	m_part->core()->openProject( projectFile );
-	
+
 	// open files to open
 	QStringList::Iterator it = m_pCurrentAppInfo->openFilesAfterGeneration.begin();
 	for( ; it != m_pCurrentAppInfo->openFilesAfterGeneration.end(); ++it )
@@ -925,6 +1045,11 @@ void AppWizardDialog::pageChanged()
 {
 	kdDebug(9010) << "AppWizardDialog::pageChanged()" << endl;
 	projectLocationChanged();
+
+	//it is possible that project name was changed - we need to update all vcs integrator dialogs
+	for (QMap<int, VCSDialog*>::iterator it = m_integratorDialogs.begin();
+		it != m_integratorDialogs.end(); ++it)
+		(*it)->init(getProjectName(), getProjectLocation());
 }
 
 void AppWizardDialog::addTemplateToFavourites()
@@ -934,17 +1059,17 @@ void AppWizardDialog::addTemplateToFavourites()
 
 void AppWizardDialog::addFavourite(QListViewItem* item, QString favouriteName)
 {
-	if(item->childCount())	
+	if(item->childCount())
 		return;
-		
+
 	ApplicationInfo* info = templateForItem(item);
-	
+
 	if(!info->favourite)
 	{
-		info->favourite = new KIconViewItem(favourites_iconview, 
-											((favouriteName=="")?info->name:favouriteName), 
+		info->favourite = new KIconViewItem(favourites_iconview,
+											((favouriteName=="")?info->name:favouriteName),
 											DesktopIcon("kdevelop"));
-											
+
 		info->favourite->setRenameEnabled(true);
 	}
 }
@@ -968,7 +1093,7 @@ void AppWizardDialog::favouritesIconViewClicked( QIconViewItem* item)
 void AppWizardDialog::removeFavourite()
 {
 	QIconViewItem* curFavourite = favourites_iconview->currentItem();
-	
+
 	//remove reference to favourite from associated appinfo
 	QPtrListIterator<ApplicationInfo> info(m_appsInfo);
 	for (; info.current(); ++info)
@@ -978,7 +1103,7 @@ void AppWizardDialog::removeFavourite()
 			info.current()->favourite = 0;
 		}
 	}
-	
+
 	//remove favourite from iconview
 	delete curFavourite;
 	curFavourite=0;
@@ -989,18 +1114,18 @@ void AppWizardDialog::populateFavourites()
 {
 	KConfig* config = kapp->config();
 	config->setGroup("AppWizard");
-	
+
 	//favourites are stored in config as a list of templates and a seperate
-	//list of icon names.  
+	//list of icon names.
 	QStringList templatesList = config->readPathListEntry("FavTemplates");
 	QStringList iconNamesList = config->readListEntry("FavNames");
-    
+
 	QStringList::Iterator curTemplate = templatesList.begin();
 	QStringList::Iterator curIconName = iconNamesList.begin();
 	while(curTemplate != templatesList.end())
 	{
 		QPtrListIterator<ApplicationInfo> info(m_appsInfo);
-		for (; info.current(); ++info) 
+		for (; info.current(); ++info)
 		{
 			if(info.current()->templateName == *curTemplate)
 			{
@@ -1018,10 +1143,10 @@ void AppWizardDialog::done(int r)
 	//need to save the template for each favourite and
 	//it's icon name.  We have a one list for the templates
 	//and one for the names.
-	
+
 	QStringList templatesList;
 	QStringList iconNamesList;
-	
+
 	//Built the stringlists for each template that has a favourite.
 	QPtrListIterator<ApplicationInfo> it(m_appsInfo);
 	for (; it.current(); ++it)
@@ -1032,7 +1157,7 @@ void AppWizardDialog::done(int r)
 			iconNamesList.append(it.current()->favourite->text());
 		}
 	}
-	
+
 	KConfig* config = kapp->config();
 	config->setGroup("AppWizard");
 	config->writePathEntry("FavTemplates", templatesList);
@@ -1057,19 +1182,19 @@ void AppWizardDialog::favouritesContextMenu(QIconViewItem* item, const QPoint& p
 
 void AppWizardDialog::setPermissions(const KArchiveFile *source, QString dest)
 {
-	kdDebug() << "AppWizardDialog::setPermissions(const KArchiveFile *source, QString dest)" << endl;
-	kdDebug() << "	dest: " << dest << endl;
-	
+	kdDebug(9010) << "AppWizardDialog::setPermissions(const KArchiveFile *source, QString dest)" << endl;
+	kdDebug(9010) << "	dest: " << dest << endl;
+
 	if (source->permissions() & 00100)
 	{
-		kdDebug() << "source is executable" << endl;
+		kdDebug(9010) << "source is executable" << endl;
 		KIO::UDSEntry entry;
 		KURL kurl = KURL::fromPathOrURL(dest);
 		if (KIO::NetAccess::stat(kurl, entry, 0))
 		{
 			KFileItem it(entry, kurl);
 			int mode = it.permissions();
-			kdDebug() << "stat shows permissions: " << mode << endl;
+			kdDebug(9010) << "stat shows permissions: " << mode << endl;
 			KIO::chmod(KURL::fromPathOrURL(dest), mode | 00100 );
 		}
 	}
@@ -1077,9 +1202,9 @@ void AppWizardDialog::setPermissions(const KArchiveFile *source, QString dest)
 
 void AppWizardDialog::setPermissions(const installFile &file)
 {
-	kdDebug() << "AppWizardDialog::setPermissions(const installFile &file)" << endl;
-	kdDebug() << "	dest: " << file.dest << endl;
-	
+	kdDebug(9010) << "AppWizardDialog::setPermissions(const installFile &file)" << endl;
+	kdDebug(9010) << "	dest: " << file.dest << endl;
+
 	KIO::UDSEntry sourceentry;
 	KURL sourceurl = KURL::fromPathOrURL(file.source);
 	if (KIO::NetAccess::stat(sourceurl, sourceentry, 0))
@@ -1088,20 +1213,116 @@ void AppWizardDialog::setPermissions(const installFile &file)
 		int sourcemode = sourceit.permissions();
 		if (sourcemode & 00100)
 		{
-			kdDebug() << "source is executable" << endl;
+			kdDebug(9010) << "source is executable" << endl;
 			KIO::UDSEntry entry;
 			KURL kurl = KURL::fromPathOrURL(file.dest);
 			if (KIO::NetAccess::stat(kurl, entry, 0))
 			{
 				KFileItem it(entry, kurl);
 				int mode = it.permissions();
-				kdDebug() << "stat shows permissions: " << mode << endl;
+				kdDebug(9010) << "stat shows permissions: " << mode << endl;
 				KIO::chmod(KURL::fromPathOrURL(file.dest), mode | 00100 );
 			}
 		}
 	}
 }
 
+QDict<KDevLicense> AppWizardDialog::licenses()
+{
+	return m_licenses;
+}
+
+void AppWizardDialog::loadLicenses()
+{
+	// kdDebug(9010) << "======================== Entering loadLicenses" << endl;
+	KStandardDirs* dirs = KGlobal::dirs();
+	dirs->addResourceType( "licenses", KStandardDirs::kde_default( "data" ) + "kdevelop/licenses/" );
+	QStringList licNames = dirs->findAllResources( "licenses", QString::null, false, true );
+
+	QStringList::Iterator it;
+	for (it = licNames.begin(); it != licNames.end(); ++it)
+	{
+		QString licPath( dirs->findResource( "licenses", *it ) );
+		kdDebug(9010) << "Loading license file: " << licPath << endl;
+		QString licName = licPath.mid( licPath.findRev('/') + 1 );
+		KDevLicense* lic = new KDevLicense( licName, licPath );
+		m_licenses.insert( licName, lic );
+	}
+	// kdDebug(9000) << "======================== Done loadLicenses" << endl;
+}
+
+void AppWizardDialog::showTemplates(bool all)
+{
+	if (all)
+	{
+		QListViewItemIterator it(templates_listview);
+		while ( it.current() ) {
+			it.current()->setVisible(true);
+			++it;
+		}
+	}
+	else
+	{
+		QPtrListIterator<ApplicationInfo> ait(m_appsInfo);
+		for (; ait.current(); ++ait) 
+		{
+			ait.current()->item->setVisible(m_profileSupport->isInTemplateList(ait.current()->templateName));
+		}
+		
+		QDictIterator<QListViewItem> dit(m_categoryMap);
+		for (; dit.current(); ++dit) 
+		{
+			//checking whether all children are not visible
+			kdDebug(9010) << "check: " << dit.current()->text(0) << endl;
+			bool visible = false;
+			QListViewItemIterator it(dit.current());
+			while ( it.current() ) {
+				if ((it.current()->childCount() == 0) && it.current()->isVisible())
+				{
+					kdDebug(9010) << "	visible: " << it.current()->text(0) << endl;
+					visible = true;
+					break;
+				}
+				++it;
+			}
+			dit.current()->setVisible(visible);
+		}
+		checkAndHideItems(templates_listview);
+	}
+}
+
+void AppWizardDialog::checkAndHideItems(QListView *view)
+{
+	QListViewItem *item = view->firstChild();
+	while (item)
+	{
+		if (!m_categoryItems.contains(item))
+			continue;
+		checkAndHideItems(item);
+		item = item->nextSibling();
+	}
+}
+
+bool AppWizardDialog::checkAndHideItems(QListViewItem *item)
+{
+	if (!m_categoryItems.contains(item))
+		return !item->isVisible();
+	QListViewItem *child = item->firstChild();
+	bool hide = true;
+	while (child)
+	{
+		hide = hide && checkAndHideItems(child);
+		child = child->nextSibling();
+	}
+	kdDebug(9010) << "check_: " << item->text(0) << " hide: " <<  hide << endl;
+	if (hide)
+	{
+		item->setVisible(false);
+		return true;
+	}
+	return false;
+}
+
 #include "appwizarddlg.moc"
 
 // kate: indent-width 4; replace-tabs off; tab-width 4; space-indent off;
