@@ -166,6 +166,8 @@ FileGroupsWidget::FileGroupsWidget(FileGroupsPart *part)
     setResizeMode(QListView::LastColumn);
     setSorting(-1);
     addColumn(i18n("Name"));
+	setAllColumnsShowFocus( true );
+
 //    addColumn(i18n("Location"));
 
     connect( this, SIGNAL(executed(QListViewItem*)),
@@ -232,7 +234,9 @@ void FileGroupsWidget::slotContextMenu(KListView *, QListViewItem *item, const Q
         // Not for group items
         FileGroupsFileItem *fvfitem = static_cast<FileGroupsFileItem*>(item);
         QString pathName = m_part->project()->projectDirectory() + QDir::separator() + fvfitem->fileName();
-        FileContext context( pathName, false);
+        KURL::List urls;
+        urls.append(pathName);
+        FileContext context(urls);
         m_part->core()->fillContextMenu(&popup, &context);
     }
     else{
