@@ -18,19 +18,25 @@
 #include <kaction.h>
 #include <kiconloader.h>
 #include <kparts/part.h>
+#include <kdevgenericfactory.h>
+#include <kdevplugininfo.h>
+#include <kapplication.h>
 
 #include "kdevproject.h"
 #include "kdevcore.h"
 #include "kdevmainwindow.h"
-#include "outputviewsfactory.h"
 #include "appoutputwidget.h"
 #include "kdevpartcontroller.h"
+#include "settings.h"
 
+static const KDevPluginInfo data("kdevappoutputview");
+typedef KDevGenericFactory< AppOutputViewPart > AppViewFactory;
+K_EXPORT_COMPONENT_FACTORY( libkdevappview, AppViewFactory( data ) )
 
 AppOutputViewPart::AppOutputViewPart(QObject *parent, const char *name, const QStringList &)
-    : KDevAppFrontend("ApplicationOutput", "appoutput", parent, name ? name : "AppOutputViewPart")
+    : KDevAppFrontend(&data, parent, name ? name : "AppOutputViewPart")
 {
-    setInstance(OutputViewsFactory::instance());
+    setInstance(AppViewFactory::instance());
 
     m_dcop = new KDevAppFrontendIface(this);
 
@@ -90,8 +96,8 @@ void AppOutputViewPart::startAppCommand(const QString &directory, const QString
     QString cmd;
 
     if (inTerminal) {
-        cmd = "konsole";
-        if ( !directory.isNull() ) {
+        cmd = Settings::terminalEmulatorName( *kapp->config() );
+        if ( cmd == "konsole" && !directory.isNull() ) {  // isn't setting the working directory below enough?
           // If a directory was specified, use it
           cmd += " --workdir " + directory;
         }
@@ -99,7 +105,7 @@ void AppOutputViewPart::startAppCommand(const QString &directory, const QString
         cmd += program;
         cmd += "; echo \"";
         cmd += i18n("Press Enter to continue!");
-        cmd += "\";read'";
+        cmd += "\";read dummy'";
     } else
         cmd = program;
 
