@@ -180,7 +180,7 @@ MakeWidget::MakeWidget(MakeViewPart *part)
 	mimeSourceFactory()->setImage("warning", QImage((const char**)warning_xpm));
 	mimeSourceFactory()->setImage("message", QImage((const char**)message_xpm));
 
-	childproc = new KShellProcess("/bin/sh");
+	childproc = new KProcess(this);
 	procLineMaker = new ProcessLineMaker( childproc );
 
 	connect( procLineMaker, SIGNAL(receivedStdoutLine(const QString&)),
@@ -230,7 +230,7 @@ void MakeWidget::queueJob(const QString &dir, const QString &command)
 	{
 		// Store the current output view so that it
 		// can be restored after a successful compilation
-		m_part->mainWindow()->storeOutputViewTab();
+// 		m_part->mainWindow()->storeOutputViewTab();
 		startNextJob();
 	}
 }
@@ -282,7 +282,8 @@ void MakeWidget::startNextJob()
 
 	childproc->clearArguments();
 	*childproc << currentCommand;
-	childproc->start(KProcess::NotifyOnExit, KProcess::AllOutput);
+	childproc->setUseShell(true);
+	childproc->start(KProcess::OwnGroup, KProcess::AllOutput);
 
 	dirstack.clear();
 	dirstack.push(new QString(dir));
@@ -293,7 +294,8 @@ void MakeWidget::startNextJob()
 
 void MakeWidget::killJob()
 {
-	childproc->kill();
+	if (!childproc->kill(SIGINT))
+		childproc->kill();
 }
 
 bool MakeWidget::isRunning()
@@ -431,6 +433,22 @@ static bool checkFileExists( const QString& file, QString& fName )
     return false;
 }
 
+void MakeWidget::specialCheck( const QString& file, QString& fName ) const
+{
+    QString firstLine = text(0);
+    QRegExp rx("cd \\'(.*)\\'.*");
+    if (rx.search(firstLine) != -1)
+    {
+        KURL url(rx.cap(1)+"/", file);
+        if (url.isValid())
+        {
+            kdDebug(9004) << "MakeWidget::specialCheck thinks that url is: " << url.url()
+                << " origin: " << file << endl;
+            fName = url.url();
+        }
+    }
+}
+
 QString MakeWidget::guessFileName( const QString& fName, int parag ) const
 {
     // pathological case
@@ -454,11 +472,12 @@ QString MakeWidget::guessFileName( const QString& fName, int parag ) const
         // no absolute path - let's guess.
         name = fName;
         if ( !checkFileExists( m_part->project()->projectDirectory() + "/" + fName, name ) &&
-	     !checkFileExists( m_part->project()->projectDirectory() + "/" + m_part->project()->activeDirectory() + "/" + fName, name ) )
-            checkFileExists( m_part->project()->buildDirectory() + "/" + fName, name );
+            !checkFileExists( m_part->project()->projectDirectory() + "/" + m_part->project()->activeDirectory() + "/" + fName, name ) &&
+            !checkFileExists( m_part->project()->buildDirectory() + "/" + fName, name ) )
+            specialCheck(fName, name);
     }
 
-    kdDebug(9004) << "Opening file: " << fName << endl;
+    kdDebug(9004) << "Opening file: " << name << endl;
 
     // GNU make resolves symlinks. if "name" is a real path to a file the
     // project know by symlink path, we need to return the symlink path
@@ -496,7 +515,6 @@ void MakeWidget::searchItem(int parag)
 			m_part->partController()->editDocument(KURL( guessFileName(item->fileName, parag) ), item->lineNum);
 		}
 		m_part->mainWindow()->statusBar()->message( item->m_error, 10000 );
-		m_part->mainWindow()->lowerView(this);
         m_lastErrorSelected = parag;
 	}
 }
@@ -522,12 +540,12 @@ void MakeWidget::slotProcessExited(KProcess *)
 	{
 		if (childproc->exitStatus())
 		{
-			KNotifyClient::event( "ProcessError", i18n("The process has finished with errors"));
+			KNotifyClient::event( topLevelWidget()->winId(), "ProcessError", i18n("The process has finished with errors"));
 			emit m_part->commandFailed(currentCommand);
 		}
 		else
 		{
-			KNotifyClient::event( "ProcessSuccess", i18n("The process has finished successfully"));
+			KNotifyClient::event( topLevelWidget()->winId(), "ProcessSuccess", i18n("The process has finished successfully"));
 			emit m_part->commandFinished(currentCommand);
 		}
 	}
@@ -545,10 +563,10 @@ void MakeWidget::slotProcessExited(KProcess *)
 	if (childproc->normalExit() && !childproc->exitStatus())
 	{
 		QTimer::singleShot(0, this, SLOT(startNextJob()));
-		if (commandList.isEmpty())
+// 		if (commandList.isEmpty())
 			// The last command on the list was successful so restore the
 			// output view to what it had before the compilation process started
-			m_part->mainWindow()->restoreOutputViewTab();
+// 			m_part->mainWindow()->restoreOutputViewTab();
 	}
 	else
 	{
@@ -800,10 +818,11 @@ void MakeWidget::toggleShowDirNavigMessages()
 void MakeWidget::updateSettingsFromConfig()
 {
 	KConfig *pConfig = kapp->config();
+	pConfig->setGroup("General Options");
+	setFont(pConfig->readFontEntry("Application Font"));
 	pConfig->setGroup("MakeOutputView");
-	setFont(pConfig->readFontEntry("Messages Font"));
 	m_bLineWrapping = pConfig->readBoolEntry("LineWrapping", true);
-	m_compilerOutputLevel = (EOutputLevel) pConfig->readNumEntry("CompilerOutputLevel", (int) eVeryShort);
+	m_compilerOutputLevel = (EOutputLevel) pConfig->readNumEntry("CompilerOutputLevel", (int) eShort);
 	DirectoryItem::setShowDirectoryMessages( pConfig->readBoolEntry("ShowDirNavigMsg", false) );
 }
 
